list.gitlab.project.files: Lists tree recursively

View source: R/gitlab.R

list.gitlab.project.filesR Documentation

Lists tree recursively

Description

Runs iteratively for all tree-type files. The tree path becomes a new path for a sub-listing.

Usage

list.gitlab.project.files(...)

Arguments

...

Arguments passed on to gitlabr::gl_list_files

project

name or id of project (not repository!)

ref

name of ref (commit branch or tag)

Value

Tibble of project files comprising tree and blob types.


royratcliffe/canny.tudor documentation built on Oct. 17, 2022, 4:17 a.m.