| vunzip_bin | R Documentation |
Vectorised unzip to raw vectors
vunzip_bin(x, ...)
x |
Vector of zip files either by name or by raw vector. |
... |
Arguments passed on to |
Zipper list of member lists of raw vector. Does not attempt to simplify the resulting list of lists of raw vectors. Consistency makes this useful since sub-lists can easily have different file names.
# Note the trailing dollar in the pattern below. Only matches path names
# ending with `zip` extension.
zippers <- canny.tudor::vunzip_bin(list.files(pattern = "*.zip$"))
# This is how you might iterate the resulting list of lists, of zippers of
# members, using nested `for` loops.
for (i in seq_along(zippers)) {
members <- zippers[[i]]
for (j in seq_along(members)) {
cat(paste(names(zippers)[[i]], names(members)[[j]], sep = ":"),
length(members[[j]]), "\n")
}
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.